"""Deprecated module for toolbox filters.

Filters placed in this module will still work - but filters should be
moved to lib/galaxy/tool_util/toolbox/filters.
"""
